instrumenttools.Piccolo
=======================

.. abjad-lineage:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo

.. autoclass:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Piccolo.Piccolo.Piccolo.__repr__
   :noindex:
